/****************************************************************************
** Meta object code from reading C++ file 'kmousetool.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kmousetool-26.07.90/kmousetool/kmousetool.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmousetool.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10KMouseToolE_t {};
} // unnamed namespace

template <> constexpr inline auto KMouseTool::qt_create_metaobjectdata<qt_meta_tag_ZN10KMouseToolE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KMouseTool",
        "settingsChanged",
        "",
        "startStopSelected",
        "defaultSelected",
        "resetSelected",
        "applySelected",
        "helpSelected",
        "closeSelected",
        "quitSelected",
        "aboutSelected",
        "configureSelected"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'settingsChanged'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startStopSelected'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'defaultSelected'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetSelected'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'applySelected'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'helpSelected'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeSelected'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'quitSelected'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'aboutSelected'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'configureSelected'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KMouseTool, qt_meta_tag_ZN10KMouseToolE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KMouseTool::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KMouseToolE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KMouseToolE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10KMouseToolE_t>.metaTypes,
    nullptr
} };

void KMouseTool::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KMouseTool *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->settingsChanged(); break;
        case 1: _t->startStopSelected(); break;
        case 2: _t->defaultSelected(); break;
        case 3: _t->resetSelected(); break;
        case 4: _t->applySelected(); break;
        case 5: _t->helpSelected(); break;
        case 6: _t->closeSelected(); break;
        case 7: _t->quitSelected(); break;
        case 8: _t->aboutSelected(); break;
        case 9: _t->configureSelected(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *KMouseTool::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMouseTool::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KMouseToolE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::KMouseToolUI"))
        return static_cast< Ui::KMouseToolUI*>(this);
    return QWidget::qt_metacast(_clname);
}

int KMouseTool::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN14KMouseToolTrayE_t {};
} // unnamed namespace

template <> constexpr inline auto KMouseToolTray::qt_create_metaobjectdata<qt_meta_tag_ZN14KMouseToolTrayE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KMouseToolTray",
        "startStopSelected",
        "",
        "configureSelected",
        "aboutSelected",
        "helpSelected"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'startStopSelected'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configureSelected'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboutSelected'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'helpSelected'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KMouseToolTray, qt_meta_tag_ZN14KMouseToolTrayE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KMouseToolTray::staticMetaObject = { {
    QMetaObject::SuperData::link<KStatusNotifierItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KMouseToolTrayE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KMouseToolTrayE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14KMouseToolTrayE_t>.metaTypes,
    nullptr
} };

void KMouseToolTray::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KMouseToolTray *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->startStopSelected(); break;
        case 1: _t->configureSelected(); break;
        case 2: _t->aboutSelected(); break;
        case 3: _t->helpSelected(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KMouseToolTray::*)()>(_a, &KMouseToolTray::startStopSelected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMouseToolTray::*)()>(_a, &KMouseToolTray::configureSelected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMouseToolTray::*)()>(_a, &KMouseToolTray::aboutSelected, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMouseToolTray::*)()>(_a, &KMouseToolTray::helpSelected, 3))
            return;
    }
}

const QMetaObject *KMouseToolTray::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMouseToolTray::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KMouseToolTrayE_t>.strings))
        return static_cast<void*>(this);
    return KStatusNotifierItem::qt_metacast(_clname);
}

int KMouseToolTray::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KStatusNotifierItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KMouseToolTray::startStopSelected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KMouseToolTray::configureSelected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KMouseToolTray::aboutSelected()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KMouseToolTray::helpSelected()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
